@import "base/all.less";
@import "font-awesome/less/font-awesome.less";
@import "preboot/preboot.less";
@import "website/variables.less";
@import "website/languages.less";
@import "website/header.less";
@import "website/dropdown.less";
@import "website/summary.less";
@import "website/body.less";
@import "website/page.less";
@import "website/buttons.less";
@import "website/markup.less";
@import "website/navigation.less";
@import "website/search.less";
@import "website/settings.less";
//@import "website/images.less";
@import "website/theme.less";
@import "website/prism.less";

* {
  .box-sizing(border-box);
  -webkit-overflow-scrolling: touch;
  -webkit-tap-highlight-color: transparent;
  -webkit-text-size-adjust: none;
  -webkit-touch-callout: none;
  -webkit-font-smoothing: antialiased;
}

a {
  text-decoration: none;
}

html,
body {
  font-size: @font-size-base;
  height: 100%;
}

body {
  text-rendering: optimizeLegibility;
  // font-smoothing: antialiased;
  font-family: @font-family-base;
  letter-spacing: .2px;
  .text-adjust(100%);
}

.spoiler {
  background-color: #2D3143;
  color: #2D3143;
}

.spoiler.hover {
  background-color: white;
}

.atTitle {
  display: flex;
}

.mermaid {
  text-align: center;
}