.alert {
    padding: 15px;
    margin-bottom: 20px;
    color: #444;
    background: #eee;
    border-bottom: 5px solid #ddd;
}

.alert-success {
    background: @state-success-bg;
    border-color: @state-success-border;
    color: @state-success-text;
}

.alert-info {
    background: @state-info-bg;
    border-color: @state-info-border;
    color: @state-info-text;
}

.alert-danger {
    background: @state-danger-bg;
    border-color: @state-danger-border;
    color: @state-danger-text;
}

.alert-warning {
    background: @state-warning-bg;
    border-color: @state-warning-border;
    color: @state-warning-text;
}
