.book.color-theme-2 {
  .panel {
    background: #1A1A1A;
    border-style: solid;
    border-color: rgba(0, 0, 0, 0.1);
    border-width: 1px;
  }

  .panel-heading {
    border-width: 0;
  }

  .panel-body {
    background: #1A1A1A;
  }

  a.section {
    border-color: #373b4e !important;
  }

  #anchorNavigationExGoTop {
    background-color: #2d3143;
    border-color: #272a3a;
    color: #bcc1d2;
  }

  #anchor-navigation-ex-pagetop-navbar {
    background-color: #2d3143;
    border-color: #272a3a;
    color: #bcc1d2;

    ul li a {
      color: #c1c6d7;
    }
  }

  #anchor-navigation-ex-navbar {
    background-color: #2d3143;
    border-color: #272a3a;
    color: #bcc1d2;

    ul li a {
      color: #c1c6d7;
    }
  }
}

.book.color-theme-1 {
  #anchor-navigation-ex-pagetop-navbar {
    background-color: #111111;
    border-color: #7e888b;
    color: #afa790;

    ul li a {
      color: #877f6a;
    }
  }

  #anchorNavigationExGoTop {
    background-color: #111111;
    border-color: #7e888b;
    color: #afa790;
  }

  #anchor-navigation-ex-navbar {
    background-color: #111111;
    border-color: #7e888b;
    color: #afa790;

    ul li a {
      color: #877f6a;
    }
  }
}